package com.yiqi.order.mapper;

import java.util.List;
import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import org.apache.ibatis.annotations.Mapper;
import com.yiqi.order.domain.OrderPurchaseGoodsItem;

/**
 * 商品订单商品信息Mapper接口
 *
 * @author ruoyi
 * @date 2023-10-20
 */
@Mapper
public interface OrderPurchaseGoodsItemMapper extends BaseMapper<OrderPurchaseGoodsItem> {
    /**
     * 查询商品订单商品信息
     *
     * @param id 商品订单商品信息主键
     * @return 商品订单商品信息
     */
    public OrderPurchaseGoodsItem selectOrderPurchaseGoodsItemById(Long id);

    /**
     * 查询商品订单商品信息列表
     *
     * @param orderPurchaseGoodsItem 商品订单商品信息
     * @return 商品订单商品信息集合
     */
    public List<OrderPurchaseGoodsItem> selectOrderPurchaseGoodsItemList(OrderPurchaseGoodsItem orderPurchaseGoodsItem);

    /**
     * 新增商品订单商品信息
     *
     * @param orderPurchaseGoodsItem 商品订单商品信息
     * @return 结果
     */
    public int insertOrderPurchaseGoodsItem(OrderPurchaseGoodsItem orderPurchaseGoodsItem);

    /**
     * 修改商品订单商品信息
     *
     * @param orderPurchaseGoodsItem 商品订单商品信息
     * @return 结果
     */
    public int updateOrderPurchaseGoodsItem(OrderPurchaseGoodsItem orderPurchaseGoodsItem);

    /**
     * 删除商品订单商品信息
     *
     * @param id 商品订单商品信息主键
     * @return 结果
     */
    public int deleteOrderPurchaseGoodsItemById(Long id);

    /**
     * 批量删除商品订单商品信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteOrderPurchaseGoodsItemByIds(Long[] ids);
}
